@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::DAGOLDEN;
 # ABSTRACT: Dist::Zilla configuration the way DAGOLDEN does it
 
-our $VERSION = '0.075';
+our $VERSION = '0.076'; # from Dist-Zilla-PluginBundle-DAGOLDEN-0.076.tar.gz
 
 # Dependencies
 use Moose 0.99;
@@ -31,8 +31,8 @@ use Dist::Zilla::Plugin::GithubMeta 0.36       ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
 use Dist::Zilla::Plugin::MetaNoIndex ();
 use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides private packages
-use Dist::Zilla::Plugin::MinimumPerl ();
-use Dist::Zilla::Plugin::PodWeaver   ();
+use Dist::Zilla::Plugin::MinimumPerl       ();
+use Dist::Zilla::Plugin::SurgicalPodWeaver ();
 use Dist::Zilla::Plugin::PromptIfStale 0.011 ();
 use Dist::Zilla::Plugin::Prereqs::AuthorDeps ();
 use Dist::Zilla::Plugin::RewriteVersion ();
@@ -251,7 +251,7 @@ sub configure {
             $self->is_task
             ? 'TaskWeaver'
             : [
-                'PodWeaver' => {
+                'SurgicalPodWeaver' => {
                     config_plugin      => $self->weaver_config,
                     replacer           => 'replace_with_comment',
                     post_code_replacer => 'replace_with_nothing',
@@ -470,7 +470,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 SYNOPSIS
 
@@ -500,8 +500,8 @@ following dist.ini:
   [ManifestSkip]      ; if -f MANIFEST.SKIP, skip those, too
 
   ; file modifications
-  [InsertCopyright    ; add copyright at "# COPYRIGHT"
-  [PodWeaver]         ; generate Pod
+  [InsertCopyright]    ; add copyright at "# COPYRIGHT"
+  [SurgicalPodWeaver]         ; generate Pod
   config_plugin = @DAGOLDEN ; my own plugin allows Pod::WikiDoc
   replacer = replace_with_comment
   post_code_replacer = replace_with_nothing
@@ -628,7 +628,7 @@ the following options:
 
 =item *
 
-C<is_task> — this indicates whether C<TaskWeaver> or C<PodWeaver> should be used.
+C<is_task> — this indicates whether C<TaskWeaver> or C<SurgicalPodWeaver> should be used.
 
 Default is 0.
 
@@ -724,28 +724,10 @@ plugins used like this:
 This PluginBundle also supports C<PluginRemover>, so dropping a plugin is as easy as this:
 
   [@DAGOLDEN]
-  -remove = Test::Portability
+  -remove = InsertCopyright
 
 =for Pod::Coverage configure mvp_multivalue_args
 
-=head1 SEE ALSO
-
-=over 4
-
-=item *
-
-L<Dist::Zilla>
-
-=item *
-
-L<Dist::Zilla::Plugin::PodWeaver>
-
-=item *
-
-L<Dist::Zilla::Plugin::TaskWeaver>
-
-=back
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
